<?php
/*
Plugin Name: PANDA Mailer
Plugin URI: http://www.schiffner.com/software/wp-panda-mailer/
Description: Adds a contact form to any WordPress page using short-codes.
Version: 1.2.3
Author: Christopher Schiffner
Author URI: http://www.schiffner.com
*/
//#############################################################################\\
//# PANDA Mailer                                                              #\\
//# Author: Christopher Schiffner - chris@schiffner.com                       #\\
//# Copyright: Christopher Schiffner - 2019                                   #\\
//#############################################################################\\
?>
<?php

add_action('admin_menu', array('wp_panda_mailer', 'wp_panda_mailer_create_menu'));
add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), array('wp_panda_mailer', 'wp_panda_mailer_add_action_links'));
add_action("wp_print_styles", array('wp_panda_mailer', 'wp_panda_mailer_styles'));
add_action("wp_print_scripts", array('wp_panda_mailer', 'wp_panda_mailer_scripts'));
add_shortcode('wp_panda_mailer', array('wp_panda_mailer', 'wp_panda_mailer_form'));
register_activation_hook( __FILE__, array('wp_panda_mailer', 'activate'));
register_deactivation_hook( __FILE__, array('wp_panda_mailer', 'deactivate'));


class wp_panda_mailer{
	
    public static function activate(){
        //initiate the plugin data structure
        $data = array( 'heading' => 'Contact',
        			   'recipients' => array(), //values: array of usernames
        			   'subjects' => array(), //values: array of usernames
        			   'formalign' => 'center',	   
                       'style' => 'responsive.php' //values: stylesheet file name in styles directory
                     );

        if ( ! get_option('wp_panda_mailer')){
            add_option('wp_panda_mailer' , $data);
        } else {
            update_option('wp_panda_mailer' , $data);
        }
    }
    public static function deactivate(){
        //clean up after ourselves
        delete_option('wp_panda_mailer');
    }




	//adds "PANDA Mailer" options link under the settings tab.
    public static function wp_panda_mailer_create_menu() {
        //add options page under the settings menu
    	add_options_page('PANDA Mailer', 'PANDA Mailer', 'manage_options', __FILE__, array('wp_panda_mailer', 'wp_panda_mailer_options'));
    }
    //adds "Settings" link on plugin page
    public static function wp_panda_mailer_add_action_links ( $links ) {
	    $mylinks = array(
	     '<a href="'.admin_url('options-general.php?page=wp-panda-mailer/wp_panda_mailer.php').'">Settings</a>',
	    );
	    return array_merge( $links, $mylinks );
    }
    //admin options page
    public static function wp_panda_mailer_options(){
        //make sure users aren't trying to bypass security
    	if ( !current_user_can( 'manage_options' ) )  {
    		wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
    	}

		$data = get_option('wp_panda_mailer');
		extract(shortcode_atts(array(
		    'heading' => $data['heading'],
		    'ary_recipients' => $data['recipients'],
		    'ary_subjects' => $data['subjects'],
		    'formalign' => $data['formalign']
		), $atts));
		
		echo "<h1>Panda Mailer Options</h1>";
		
        //Update settings
        if(isset($_POST['action'])){
        
        	switch($_POST['action']){
        		case 'deleterecipient':
        			unset($ary_recipients[$_POST['recipient']]);
        			$data['recipients']=$ary_recipients;
        			echo '<br/><div id="message" class="updated"><p>Recipient Deleted</p></div>';
        			break;
        			
        		case 'deletesubject':
        			unset($ary_subjects[$_POST['subject']]);
        			$data['subjects']=$ary_subjects;
        			echo '<br/><div id="message" class="updated"><p>Subject Deleted</p></div>';
        			break;
        			
        		case 'addrecipient':
        			$name=$_POST['name'];
        			$email=$_POST['email'];
        			$ary_recipients[]=array($name, $email);
        			$data['recipients']=$ary_recipients;
        			echo '<br/><div id="message" class="updated"><p>Recipient Added</p></div>';
        			break;
        			
        		case 'addsubject':
        			$subject=$_POST['subject'];
        			$ary_subjects[]=$subject;
        			$data['subjects']=$ary_subjects;
        			echo '<br/><div id="message" class="updated"><p>Subject Added</p></div>';
        			break;
        			
        		case 'savesettings':
        			$heading=$_POST['heading'];
        			$formalign=$_POST['formalign'];
        			$data['heading']=$heading;
        			$data['formalign']=$formalign;
        			echo '<br/><div id="message" class="updated"><p>Settings Saved</p></div>';
        			break;
        	}
            
            update_option('wp_panda_mailer', $data);
        }

		echo "<style>
			  .wp_panda_mailer_admin_list_container{
					clear: both;
					width: 96%;
					max-width: 700px;
			  		margin: 50px 0 auto;
			  		text-align: center;
			  		border: 2px solid #ccc;
			  		background: #f7f7f7;
			  		padding: 0 20px 20px 20px;
			  		font-size: 1.1em;
			  }
			  .wp_panda_mailer_admin_list_container form{
			  		clear: both;
			  		text-align: left;
			  		margin: 0 auto;
			  		text-align: center;
			  }
			  .wp_panda_mailer_admin_list_container form .submit_center{
			  		display: block;
			  		width: 150px;
			  		margin: 0 auto;
			  }
			  .wp_panda_mailer_admin_list_container .section_title{
			  		clear: both;
			  		width: 150px;
			  		margin: -12px 0 20px 25px;
			  		text-align: center;
			  		border: 2px solid #ccc;
			  		background: #fff;
			  		font-weight: bold;
			  		font-size: 1.2em;
			  }
			  .wp_panda_mailer_admin_list_container table{
			  	display: block;
			  	width: 100%;
			  	max-width: 500px;
			  	margin: 0 auto;
			  	margin-bottom: 15px;
			  	padding: 0;
			  }
			  .wp_panda_mailer_admin_list_container table .odd{
			  	background: #fff;
			  	border-top: 1px solid #ccc;
			  	border-bottom: 1px solid #ccc;
			  }
			  .wp_panda_mailer_admin_list_container table .odd td{
			  	border-top: 1px solid #ccc;
			  	border-bottom: 1px solid #ccc;
			  }
			  .wp_panda_mailer_admin_list_container table td{
			  	padding: 5px 10px 5px 10px;
			  	text-align: left;
			  }
			  .wp_panda_mailer_admin_list_container table tr{
			  	width: 100%;
			  }
			  </style>";
        
        echo "<div class='wp_panda_mailer_admin_list_container' style='text-align: left;'>
        	  <div class='section_title'>How To Use</div>
        
        	  To display the contact form paste the shortcode <strong>[wp_panda_mailer]</strong> on any page or post you want the contact form displayed on.
        	  
        	  <br/><br/><strong>Configuration</strong><br/>To add recipients or subjects use the forms below. You must add at least one recipient and one subject for the form to work. If more than one recipient or subject is added, users will be presented with recipient and subject drop-down menus.
        	  
        	  <br/><br/><strong>Groups</strong><br/>To create a mailing group simply enter a comma separate list of email addresses in the 'Email(s)' field when adding a recipient. You may enter any display name you wish to identify your group by. 
        	  
        	  <br/><br/><strong>Shortcode</strong><br/>[wp_panda_mailer]
        	  
        	  </div>";
        	  	  
        echo "<div class='wp_panda_mailer_admin_list_container'>
        	  <div class='section_title'>Recipients</div>
        
        	  <table cellspacing='0'>
        		 <tr><td></td><td><strong>Display Name</strong></td><td><strong>Email Address</strong></td></tr>";
        $rowclasser="odd";
        foreach ($ary_recipients as $recipientkey => $recipient) {
            
            $recipient[0] = stripslashes($recipient[0]);
            
        	echo "<tr class='".$rowclasser."'>
        			<td width='14%'><form action='?page=wp-panda-mailer/wp_panda_mailer.php' method='POST'><input type='hidden' name='action' value='deleterecipient' /><input type='hidden' name='recipient' value='".$recipientkey."' /><input type='submit' value='delete'></form></td>
        			<td width='43%'>".$recipient[0]."</td>
        			<td width='43%'>".$recipient[1]."</td>
        		  </tr>";
        	if($rowclasser == "odd"){
        		$rowclasser = "even";
        	}else{
        		$rowclasser = "odd";
        	}
        }
        echo "</table>
        
        	  <form action='?page=wp-panda-mailer/wp_panda_mailer.php' method='POST'>
        	  <input type='hidden' name='action' value='addrecipient' />
        	  <label>Display Name: </label><input type='text' name='name' value='' />&nbsp;&nbsp;&nbsp;&nbsp;
        	  <label>Email(s): </label><input type='text' name='email' value='' />
        	  <input type='submit' value='Add Recipient'>
        	  </form>
        	  
        	  </div>";



		echo "<div class='wp_panda_mailer_admin_list_container'>
			  <div class='section_title'>Subjects</div>
		
			  <table cellspacing='0'>
				 <tr><td></td><td><strong>Subject</strong></td></tr>";
		$rowclasser="odd";
        foreach ($ary_subjects as $subjectkey => $subject) {
            
            $subject = stripslashes($subject);
            
        	echo "<tr class='".$rowclasser."'>
        			<td width='14%'><form action='?page=wp-panda-mailer/wp_panda_mailer.php' method='POST'><input type='hidden' name='action' value='deletesubject' /><input type='hidden' name='subject' value='".$subjectkey."' /><input type='submit' value='delete'></form></td>
        			<td width='86%'>".$subject."</td>
        		  </tr>";
        	if($rowclasser == "odd"){
        		$rowclasser = "even";
        	}else{
        		$rowclasser = "odd";
        	}
        }
        echo "</table>
        
        	  <form action='?page=wp-panda-mailer/wp_panda_mailer.php' method='POST'>
        	  <input type='hidden' name='action' value='addsubject' />
        	  <label>Subject: </label><input type='text' name='subject' value='' />
        	  <input type='submit' value='Add Subject'>
        	  </form>
        	  </div>";
		
		
		
		switch($formalign){
			case 'left':
				$left_selected="SELECTED";
				break;
				
			case 'center':
				$center_selected="SELECTED";
				break;
				
			case 'right':
				$right_selected="SELECTED";
				break;
		}
		
		echo "<div class='wp_panda_mailer_admin_list_container'>
			  <div class='section_title'>Settings</div>
			  
			  <form action='?page=wp-panda-mailer/wp_panda_mailer.php' method='POST' style='text-align: left;'>
			  <input type='hidden' name='action' value='savesettings' />
			  <label>Form Heading: </label><input type='text' name='heading' value='".$heading."' />
			  <br/><label>Form Position: </label>
				  <select name='formalign'>
					  <option value='left' $left_selected>Left</option>
					  <option value='center' $center_selected>Center</option>
					  <option value='right' $right_selected>Right</option>
				  </select>
			  <br/><br/><input type='submit' value='Save Settings' class='submit_center'>
			  </form>
			  
			  </div>";
    }



	//injects styles for form
    public static function wp_panda_mailer_styles(){
        //load options
        $data = get_option('wp_panda_mailer');

        wp_register_style('wp_panda_mailer', plugin_dir_url(__FILE__).'styles/'.$data['style'], false, "1.0.0");
        wp_enqueue_style( 'wp_panda_mailer');
    }
    //injects scripts for form.
    public static function wp_panda_mailer_scripts(){
    
    	wp_enqueue_script("jquery");
    	
	    wp_register_script( 'wp_panda_mailer_script_1', plugin_dir_url(__FILE__).'scripts/jquery.watermarkinput.js', false, "1.0.0", true );
	    wp_enqueue_script( 'wp_panda_mailer_script_1');
	    
    	wp_register_script( 'wp_panda_mailer_script_2', plugin_dir_url(__FILE__).'scripts/panda_mailer.js', false, "1.0.0", true );
    	wp_enqueue_script( 'wp_panda_mailer_script_2');
    }



	//called by shortcode to display form
    public static function wp_panda_mailer_form($atts, $content = null) {
    	
        //get database variables
        $data = get_option('wp_panda_mailer');

        extract(shortcode_atts(array(
            'heading' => $data['heading'],
            'ary_recipients' => $data['recipients'],
            'ary_subjects' => $data['subjects'],
            'formalign' => $data['formalign']
    	), $atts));
    	
    	switch($formalign){
    		case 'left':
    			$content .= "<style type='text/css'>form#wp_panda_mailer{ clear: both; text-align: left; float: left;} </style>";
    			break;
    			
    		case 'right':
    			$content .= "<style type='text/css'>form#wp_panda_mailer{ clear: both; align: right; float: right; } </style>";
    			break;
    			
    		default:
    			$content .= "<style type='text/css'>form#wp_panda_mailer{ clear: both; margin: 0 auto; } </style>";
				break;
    	}
    		
    	//Start Form
    	$content .= "<form method='post' action='".plugin_dir_url(__FILE__)."wp_panda_mailer_send.php' onsubmit=\"return wp_panda_mailer_checkform(this);\" id='wp_panda_mailer'>
					<a name='wp_panda_mailer'><h2>".$heading."</h2></a>";
		
		//user feedback
		$error="";
		$from="";
		$message="";
		$recipient=-1;
		$subject=-1;
		
		if(isset($_GET['wppmerror'])){
		    $error=urldecode($_GET['wppmerror']);
		    $from=urldecode($_GET['from']);
		    $message=urldecode($_GET['message']);
		    $recipient=urldecode($_GET['recipient']);
		    $subject=urldecode($_GET['subject']);
		    
		    switch($error){
		        case 'fieldBlank':
			    //blank field error
		    	$content .= "<div class='wp_panda_mailer_error'>You left a field blank. All fields must be completed.</div>";
			    break;
			case 'codeMismatch':
			    //code mismatch error
			    $content .= "<div class='wp_panda_mailer_error'>The human verification code you entered was not correct</div>";
			    break;
			case 'invalidEmail':
			    //code mismatch error
			    $content .= "<div class='wp_panda_mailer_error'>You did not enter a valid email address.</div>";
			    break;
			case 'invalidEmailHost':
			    //code mismatch error
			    $content .= "<div class='wp_panda_mailer_error'>The from email address domain cannot be the same as the server hostname (".gethostname().").</div>";
			    break;
			case 'sent':
			    //message sent
			    $content .= "<div class='wp_panda_mailer_sent'>Your message has been delivered</div>";
			    break;
		    }
		}else{
			if(isset($_GET['subject'])){
				$subject=urldecode($_GET['subject']);
			}
			if(isset($_GET['recipient'])){
				$subject=urldecode($_GET['recipient']);
			}
		}
					
					
	    $content .= "<div class='wp_panda_mailer_user-email-label'>Your email address</div>
	    		    <input type='text' id='wp_panda_mailer_user-email-input' name='from' value='".$from."' />
	    			
	    			<div class='wp_panda_mailer_user-website-label' style='display: none !important'>Your website</div>
	    			<input type='text' id='wp_panda_mailer_user-website-input' name='website' value='' style='display: none !important' />
	    			
	    					    
	    		    <img class='wp_panda_mailer_auth-images wp_panda_mailer_hide' id='wp_panda_mailer_email-pass' src='".plugin_dir_url(__FILE__)."images/pass.png' />
	    		    <img class='wp_panda_mailer_auth-images wp_panda_mailer_hide' id='wp_panda_mailer_email-fail' src='".plugin_dir_url(__FILE__)."images/fail.png' />
	    	
	    		    <!-- recipient list -->";
    	
    	            
    	
    	//if we have one recipient & the user still wants it displayed -- display it.
    	//if we have one recipient & the user doesnt want it displayed then use a hidden input.
    	//if we have more than one recipient display the list.
    	//else die as there are no recipient.
    	if(count($ary_recipients)==1){
			$content .= "<input type='hidden' name='recipient' value='0'>";
		}else if(count($ary_recipients)>1){
			$content .= "<div class='wp_panda_mailer_recipient-list-label'>To</div>";
			$content .= "<select id='wp_panda_mailer_recipient-list' name='recipient'>";
			$content .= "<option value='-1'> --please select a recipient -- </option>";
    
			foreach($ary_recipients as $tempkey => $tempvalue){
    	        
                $tempvalue[0] = stripslashes($tempvalue[0]);
                
				if($tempkey == $recipient){
					$selected="selected='selected'";
				}else{
					$selected="";
				}
    	
				$content .= "<option value='{$tempkey}' $selected>$tempvalue[0]</option>";
			}
			$content .= "</select>";
		}else{
			//die("You must specify a recipient in pandamail_config.php");
    	}
    	
    	//we don't want phantom verification images. Lets now add them in conditions they would appear.
    	if(count($ary_recipients)>1){
			$content .= "<img class='wp_panda_mailer_auth-images wp_panda_mailer_hide' id='wp_panda_mailer_recipient-pass' src='".plugin_dir_url(__FILE__)."images/pass.png' />";
			$content .= "<img class='wp_panda_mailer_auth-images wp_panda_mailer_hide' id='wp_panda_mailer_recipient-fail' src='".plugin_dir_url(__FILE__)."images/fail.png' />";
    	}
    	
    	$content .= "<!-- subject list -->";
    
    	//if we have one subject & the user still wants it displayed -- display it.
    	//if we have one subject & the user doesnt want it displayed then use a hidden input.
    	//if we have more than one subject display the list.
    	//else die as there are no subjects.
    	if(count($ary_subjects)==1){
			$content .= "<input type='hidden' name='subject' value='0'>";
		}else if(count($ary_subjects)>1){
			$content .= "<div class='wp_panda_mailer_subject-list-label'>Subject</div>";
			$content .= "<select id='wp_panda_mailer_subject-list' name='subject'>";

			$content .= "<option value='-1'> --please select a subject -- </option>";
			foreach($ary_subjects as $tempkey => $tempvalue){
                
                $tempvalue = stripslashes($tempvalue);
	    	
				if(intval($subject) == $tempkey){
					$selected="selected='selected'";
				}else{
					$selected="";
				}
	    	
				$content .= "<option value='{$tempkey}' $selected>$tempvalue</option>";
			}
			$content .= "</select>";
		}else{
			//die("You must specify a subject in pandamail_config.php");
    	}
    	
    	//we don't want phantom verification images. Lets now add them in conditions they would appear.
    	if(count($ary_subjects)>1){
			$content .= "<img class='wp_panda_mailer_auth-images wp_panda_mailer_hide' id='wp_panda_mailer_subject-pass' src='".plugin_dir_url(__FILE__)."images/pass.png' />";
			$content .= "<img class='wp_panda_mailer_auth-images wp_panda_mailer_hide' id='wp_panda_mailer_subject-fail' src='".plugin_dir_url(__FILE__)."images/fail.png' />";
    	}
    	

		$content .= "<div class='wp_panda_mailer_message-label'>Message
    		    	<img class='wp_panda_mailer_auth-images wp_panda_mailer_hide' id='wp_panda_mailer_message-pass' src='".plugin_dir_url(__FILE__)."images/pass.png' />
    	            <img class='wp_panda_mailer_auth-images wp_panda_mailer_hide' id='wp_panda_mailer_message-fail' src='".plugin_dir_url(__FILE__)."images/fail.png' />
    	            </div>
    	            <textarea id='wp_panda_mailer_user-message' name='message'>".$message."</textarea>

    				<!-- human verification image -->
    				<div class='wp_panda_mailer_verification-image-label'>Type the verification code in the box</div>
    				<div id='wp_panda_mailer_verification'>
    					<img id='wp_panda_mailer_verification-image' src='".plugin_dir_url(__FILE__)."includes/panda_captcha_for_wp_panda_mailer.php' />
    					<input type='text' id='wp_panda_mailer_verification-code' name='response' />
    					<img class='wp_panda_mailer_auth-images wp_panda_mailer_hide' id='wp_panda_mailer_captcha-pass' src='".plugin_dir_url(__FILE__)."images/pass.png' />
    	    			<img class='wp_panda_mailer_auth-images wp_panda_mailer_hide' id='wp_panda_mailer_captcha-fail' src='".plugin_dir_url(__FILE__)."images/fail.png' />
    		    	</div>
    		    	<input type='hidden' name='returnto' value='".get_permalink()."' />
    		    	
    				<!-- submit button -->
    				<div class='wp_panda_mailer_send-clear'></div>
    				<input id='wp_panda_mailer_send-message' type='submit' value= 'Send Message' />
    				</form>";
    
    	return $content;
    	
    }
}
?>